@@ -21,28 +21,22 @@
 
 #include <gtk/gtk.h>
 
-static inline GtkWidget* topmost_parent(GtkWidget* widget)
-{
-  for(; widget && widget->parent; widget = widget->parent);
-  return widget;
+static inline GtkWidget* topmost_parent(GtkWidget* widget) {
+	for (; widget && widget->parent; widget = widget->parent);
+	return widget;
 }
 
-extern	GtkWidget *dialog_create_modal_transient_window (const char *title, 
-                int close_on_esc, int allow_resize, GtkSignalFunc on_destroy);
+extern GtkWidget *dialog_create_modal_transient_window (const char *title, int close_on_esc, int allow_resize, GtkSignalFunc on_destroy);
 
-extern	void dialog_ok (const char *title, const char *fmt, ...) G_GNUC_PRINTF(2, 3);
-extern	int dialog_yesno (const char *title, int defbutton, char *yes, char *no, 
-                                                              char *fmt, ...) G_GNUC_PRINTF(5, 6);
-extern	int dialog_yesnoredial (const char *title, int defbutton, char *yes, char *no, char *redial,
-                                                              char *fmt, ...) G_GNUC_PRINTF(6, 7);
-extern	char *enter_string_dialog (int visible, char *fmt, ...) G_GNUC_PRINTF(2, 3);
-extern	char *enter_string_with_option_dialog (
-                      int visible, char *optstr, int *optval, char *fmt, ...) G_GNUC_PRINTF(4, 5);
+extern void dialog_ok (const char *title, const char *fmt, ...) G_GNUC_PRINTF(2, 3);
+extern int dialog_yesno (const char *title, int defbutton, char *yes, char *no, char *fmt, ...) G_GNUC_PRINTF(5, 6);
+extern int dialog_yesnoredial (const char *title, int defbutton, char *yes, char *no, char *redial, char *fmt, ...) G_GNUC_PRINTF(6, 7);
+extern char *enter_string_dialog (int visible, char *fmt, ...) G_GNUC_PRINTF(2, 3);
+extern char *enter_string_with_option_dialog (int visible, char *optstr, int *optval, char *fmt, ...) G_GNUC_PRINTF(4, 5);
 
 void about_dialog (GtkWidget *widget, gpointer data);
 
-/** Create a new file selection widget
- */
+/** Create a new file selection widget */
 GtkWidget* file_dialog(const char *title, GtkSignalFunc ok_callback, gpointer data);
 
 /** create new file_dialog and connect the ok button to the textentry */
