@@ -19,15 +19,10 @@
 
 #include <GeoIP.h>
 
-const char GeoIP_country_code[247][3];
-const char * GeoIP_country_name[247];
-
-GEOIP_API GeoIP* GeoIP_new(int flags)
-{
+GEOIP_API GeoIP* GeoIP_new(int flags) {
 	return 0;
 }
 
-GEOIP_API GeoIP* GeoIP_open(const char * filename, int flags)
-{
+GEOIP_API GeoIP* GeoIP_open(const char * filename, int flags) {
 	return 0;
 }
