@@ -20,7 +20,6 @@
 #ifndef _MEMTOPIXMAP_H_
 #define _MEMTOPIXMAP_H_
 
-void renderMemToGtkPixmap(const guchar* mem, size_t len,
-    GdkPixmap **pix, GdkBitmap **mask, guint* width, guint* height, unsigned char brightness);
+void renderMemToGtkPixmap(const guchar* mem, size_t len, GdkPixmap **pix, GdkBitmap **mask, guint* width, guint* height, unsigned char brightness);
 
 #endif
