@@ -27,38 +27,23 @@
 
 
 void iconify_window (GdkWindow *window) {
-  Window xwindow;
+	Window xwindow;
 
-  if (!window)
-    return;
+	if (!window)
+		return;
 
+	xwindow = GDK_WINDOW_XWINDOW(window);
 
-
-  xwindow = GDK_WINDOW_XWINDOW(window);
-
-
-  XIconifyWindow (GDK_DISPLAY (), xwindow, DefaultScreen (GDK_DISPLAY ()));
+	XIconifyWindow (GDK_DISPLAY (), xwindow, DefaultScreen (GDK_DISPLAY ()));
 }
 
-static const char* minimize_icon = "xqf_48x48.png";
+static const char* minimize_icon = "xqf.svg";
 
-void window_set_icon (GtkWidget *win)
-{
-#ifdef USE_GTK2
-  GdkPixbuf* pixbuf;
-  pixbuf = load_pixmap_as_pixbuf(minimize_icon);
-  if(pixbuf)
-  {
-    gtk_window_set_icon (GTK_WINDOW (win), pixbuf);
-    gdk_pixbuf_unref (pixbuf);
-  }
-#else
-  static struct pixmap pix;
-
-  if(!load_pixmap_as_pixmap(win, minimize_icon, &pix))
-    return;
-
-  gdk_window_set_icon(win->window, NULL, pix.pix, pix.mask);
-  gdk_window_set_icon_name(win->window, "XQF");
-#endif
+void window_set_icon (GtkWidget *win) {
+	GdkPixbuf* pixbuf;
+	pixbuf = load_pixmap_as_pixbuf(minimize_icon);
+	if (pixbuf) {
+		gtk_window_set_icon (GTK_WINDOW (win), pixbuf);
+		g_object_unref (pixbuf);
+	}
 }
